@@ -666,13 +666,13 @@ impl Client {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::retry_loop_for_pattern;
     use crate::utils::test_utils::{create_test_client, gen_ed_keypair};
     use anyhow::{anyhow, bail, Result};
     use sn_data_types::{MapAction, MapKind, Token};
     use sn_messaging::client::Error as ErrorMessage;
     use std::str::FromStr;
     use std::time::Duration;
-    use tokio::time::sleep;
     use xor_name::XorName;
 
     // 1. Create unseq. map with some entries and perms and put it on the network
@@ -698,7 +698,7 @@ mod tests {
 
         let mut res: Result<u64> = Err(anyhow!("Timeout!".to_string()));
         while res.is_err() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             res = match client
                 .get_map_version(MapAddress::Unseq { name, tag })
                 .await
@@ -755,7 +755,7 @@ mod tests {
 
         let mut res: Result<MapSeqEntries> = Err(anyhow!("Timeout!".to_string()));
         while res.is_err() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             res = match client.list_seq_map_entries(name, tag).await {
                 Ok(res) => Ok(res),
                 Err(error) => Err(error.into()), // into anyhow error
@@ -801,7 +801,7 @@ mod tests {
 
         let mut res = client.get_map(address).await;
         while res.is_ok() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             // Keep trying until it fails
             res = client.get_map(address).await;
         }
@@ -942,7 +942,7 @@ mod tests {
         // Assert that the data is stored.
         let mut res = client.get_map(address).await;
         while res.is_err() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             res = client.get_map(address).await;
         }
 
@@ -960,7 +960,7 @@ mod tests {
             .list_map_user_permissions(MapAddress::Seq { name, tag }, user)
             .await?;
         while permissions.is_allowed(MapAction::Insert) {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             permissions = client
                 .list_map_user_permissions(MapAddress::Seq { name, tag }, user)
                 .await?;
@@ -979,7 +979,7 @@ mod tests {
             .list_map_permissions(MapAddress::Seq { name, tag })
             .await?;
         while permissions.len() != 1 {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             permissions = client
                 .list_map_permissions(MapAddress::Seq { name, tag })
                 .await?;
@@ -1030,7 +1030,7 @@ mod tests {
         let mut res = client.get_map(address).await;
 
         while res.is_err() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             res = client.get_map(address).await;
         }
         let fetched_entries = client.list_seq_map_entries(name, tag).await?;
@@ -1114,7 +1114,7 @@ mod tests {
         // Assert that the data is stored.
         let mut res = client.get_map(address).await;
         while res.is_err() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(Duration::from_millis(200)).await;
             res = client.get_map(address).await;
         }
 
@@ -1168,11 +1168,11 @@ mod tests {
 
         let balance_before_delete = client.get_balance().await?;
         client.delete_map(map_address).await?;
-        let new_balance = client.get_balance().await?;
 
         // make sure we have _some_ balance
-        assert_ne!(balance_before_delete, Token::from_str("0")?);
-        assert_ne!(balance_before_delete, new_balance);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal != Token::from_str("0")?);
+        // and its not the same as before
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal != balance_before_delete);
 
         Ok(())
     }
